import { Construct, IConstruct } from '@aws-cdk/cdk';
export interface ICertificate extends IConstruct {
    /**
     * The certificate's ARN
     */
    readonly certificateArn: string;
    /**
     * Export this certificate from the stack
     */
    export(): CertificateImportProps;
}
/**
 * Reference to an existing Certificate
 */
export interface CertificateImportProps {
    /**
     * The certificate's ARN
     */
    readonly certificateArn: string;
}
/**
 * Properties for your certificate
 */
export interface CertificateProps {
    /**
     * Fully-qualified domain name to request a certificate for.
     *
     * May contain wildcards, such as ``*.domain.com``.
     */
    readonly domainName: string;
    /**
     * Alternative domain names on your certificate.
     *
     * Use this to register alternative domain names that represent the same site.
     */
    readonly subjectAlternativeNames?: string[];
    /**
     * What validation domain to use for every requested domain.
     *
     * Has to be a superdomain of the requested domain.
     *
     * @default Apex domain is used for every domain that's not overridden.
     */
    readonly validationDomains?: {
        [domainName: string]: string;
    };
}
/**
 * A certificate managed by AWS Certificate Manager
 *
 * IMPORTANT: if you are creating a certificate as part of your stack, the stack
 * will not complete creating until you read and follow the instructions in the
 * email that you will receive.
 *
 * ACM will send validation emails to the following addresses:
 *
 *  admin@domain.com
 *  administrator@domain.com
 *  hostmaster@domain.com
 *  postmaster@domain.com
 *  webmaster@domain.com
 *
 * For every domain that you register.
 */
export declare class Certificate extends Construct implements ICertificate {
    /**
     * Import a certificate
     */
    static import(scope: Construct, id: string, props: CertificateImportProps): ICertificate;
    /**
     * The certificate's ARN
     */
    readonly certificateArn: string;
    constructor(scope: Construct, id: string, props: CertificateProps);
    /**
     * Export this certificate from the stack
     */
    export(): CertificateImportProps;
}
